//---------------------------------------------------------------------------------
/// \file	SimpleCommand.cpp
/// \author	Rob Bateman [robthebloke@hotmail.com]
/// \date	2-7-2004
/// \brief	A really basic example of MComputation
///
//---------------------------------------------------------------------------------

// to compile:
//
//		mayald -shared -o computation.so main.cpp
//

#ifdef WIN32
	#define NT_PLUGIN
#endif


// required to link the libraries
#ifdef WIN32
	#pragma comment(lib,"Foundation.lib")
	#pragma comment(lib,"OpenMaya.lib")
	#pragma comment(lib,"OpenMayaFx.lib")
	#pragma comment(lib,"OpenMayaUi.lib")
	#pragma comment(lib,"Image.lib")
	#pragma comment(lib,"OpenMayaAnim.lib")
#endif

// include any maya headers we need.
#include <maya/MSimple.h>
#include <maya/MGlobal.h>
#include <maya/MMatrix.h>
#include <maya/MFnMesh.h>
#include <maya/MFnTransform.h>
#include <maya/MItDependencyNodes.h>
#include <maya/MPointArray.h>
#include <maya/MComputation.h>

//---------------------------------------------------------------------------------
// Use a helper macro to register a command with Maya.  This creates and
// registers a command that does not support undo or redo.  The
// created class derives off of MPxCommand.
//
DeclareSimpleCommand( computation, "A simple mel function example", "1.0");


//---------------------------------------------------------------------------------
/// \brief	This function impliments our very first simple command plugin.
/// \param	args - the argument list that was passes to the command from MEL
/// \return	MS::kSuccess - command succeeded
///			MS::kFailure - command failed (returning this value will cause the
///         	           MEL script that is being run to terminate unless the
///         	           error is caught using a "catch" statement.
///
MStatus computation::doIt( const MArgList& args )

{
	// create an MComputation class for heavy calculation type things
	MComputation Interupter;

	// set the start of the heavy computation
	Interupter.beginComputation();

		// now do all of your computation safe in the knowledge you can press esapce
		// at any time (here, i'm just looping infinately....)
		//
		while(1) {

			// check the computation to see if it's been interupted!
			if( Interupter.isInterruptRequested() )
			{
				return MS::kFailure;
			}

		}

	// finished our computation
	Interupter.endComputation();

	return MS::kSuccess;
}













































